@@ -20,15 +20,11 @@
 #' @importFrom rlang `:=` `!!`
 #' @importFrom shinyFeedback useShinyFeedback feedbackDanger
 #' @importFrom fontawesome fa_i
+#' @importFrom utils getFromNamespace
 NULL
 
 globalVariables(".")
 
-is_col_style_structure <- utils::getFromNamespace("is_col_style_structure","tfrmt")
-split_data_names_to_df <- utils::getFromNamespace("split_data_names_to_df","tfrmt")
-make_mock_data <- utils::getFromNamespace("make_mock_data","tfrmt")
-apply_tfrmt <- utils::getFromNamespace("apply_tfrmt","tfrmt")
-
 
 
 
